(client-card-parser client-parser)(client-card-parser client-parser
{:com.wsscode.pathom.viz.query-editor/keys
[wrap-run-query]})Returns a new parser that will use the card-parser setting the client
parser to be client-parser.
Returns a new parser that will use the card-parser setting the client parser to be `client-parser`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |